@@ -5,11 +5,8 @@
  * Licensed under the MIT License.
  */
 
-'use strict';
-
-require('mocha');
-var assert = require('assert');
-var isPlainObject = require('..');
+import assert from 'assert';
+import { isPlainObject } from '../is-plain-object.js';
 
 describe('Same-Realm Server Tests', function() {
   it('should return `true` if the object is created by the `Object` constructor.', function() {
@@ -17,6 +14,7 @@ describe('Same-Realm Server Tests', function() {
     assert(isPlainObject(Object.create(Object.prototype)));
     assert(isPlainObject({foo: 'bar'}));
     assert(isPlainObject({}));
+    assert(isPlainObject(Object.create(null)));
   });
 
   it('should return `false` if the object is not created by the `Object` constructor.', function() {
@@ -29,6 +27,5 @@ describe('Same-Realm Server Tests', function() {
     assert(!isPlainObject([]));
     assert(!isPlainObject(new Foo));
     assert(!isPlainObject(null));
-    assert(!isPlainObject(Object.create(null)));
   });
 });
